package com.ruoyi.system.mapper;

import java.util.List;
import com.ruoyi.system.domain.WyPlatformBillTemplate;
import com.ruoyi.system.domain.WyPlatformBillTemplateExportLog;

/**
 * 酒单套打模板Mapper接口
 * 
 * @author ruoyi
 * @date 2025-02-15
 */
public interface WyPlatformBillTemplateMapper 
{
    /**
     * 查询酒单套打模板
     * 
     * @param id 酒单套打模板主键
     * @return 酒单套打模板
     */
    public WyPlatformBillTemplate selectWyPlatformBillTemplateById(Long id);

    /**
     * 查询酒单套打模板列表
     * 
     * @param wyPlatformBillTemplate 酒单套打模板
     * @return 酒单套打模板集合
     */
    public List<WyPlatformBillTemplate> selectWyPlatformBillTemplateList(WyPlatformBillTemplate wyPlatformBillTemplate);

    /**
     * 新增酒单套打模板
     * 
     * @param wyPlatformBillTemplate 酒单套打模板
     * @return 结果
     */
    public int insertWyPlatformBillTemplate(WyPlatformBillTemplate wyPlatformBillTemplate);

    /**
     * 修改酒单套打模板
     * 
     * @param wyPlatformBillTemplate 酒单套打模板
     * @return 结果
     */
    public int updateWyPlatformBillTemplate(WyPlatformBillTemplate wyPlatformBillTemplate);

    /**
     * 删除酒单套打模板
     * 
     * @param id 酒单套打模板主键
     * @return 结果
     */
    public int deleteWyPlatformBillTemplateById(Long id);

    /**
     * 批量删除酒单套打模板
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteWyPlatformBillTemplateByIds(Long[] ids);


    public List<WyPlatformBillTemplateExportLog> selectTemplateExportLogList(WyPlatformBillTemplateExportLog wyPlatformBillTemplateExportLog);

    public int insertTemplateExportLog(WyPlatformBillTemplateExportLog wyPlatformBillTemplateExportLog);

    public int updateTemplateExportLog(WyPlatformBillTemplateExportLog wyPlatformBillTemplateExportLog);

    public int deleteTemplateExportLog(Long id);

    public WyPlatformBillTemplateExportLog selectTemplateExportLogById(Long id);
}
